Test Report

# Summary

Started | 2025-09-04 12:49:45
Ended | 2025-09-04 12:59:06
Duration | 0:09:21.426308
Total run time | 0:09:04.930530

100 passed 5 skipped

# Warnings

## Warnings 189

- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:98
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:102
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:73
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:67
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:115
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:107
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/polymer_enmap.py:53
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/level1_enmap.py:67
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Automatic nodata value detection returned the value 0.0 for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER' but this seems to be unreliable (occurs in only 2 image corners). To avoid automatic detection, just pass the correct nodata value.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/geoarray/baseclasses.py:806
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66

# Tests

## tests/test_cli_parser.py 7 0:00:00.731595

### PASSED Test_CLIParser::test_json_opts 0:00:00.192097

Started | 2025-09-04 12:49:57
Ended | 2025-09-04 12:49:57
Duration | 0:00:00.192097
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_output_nodata_value 0:00:00.119798

Started | 2025-09-04 12:49:57
Ended | 2025-09-04 12:49:57
Duration | 0:00:00.119798
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.080809

Started | 2025-09-04 12:49:57
Ended | 2025-09-04 12:49:57
Duration | 0:00:00.080809
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_boolean 0:00:00.128447

Started | 2025-09-04 12:49:57
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.128447
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_list 0:00:00.046770

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.046770
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtepsg 0:00:00.081818

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.081818
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtprj 0:00:00.081857

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.081857
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_config.py 13 0:00:00.380110

### PASSED Test_get_options::test_target_is_file_no_validation 0:00:00.008377

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.008377
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_get_options::test_target_is_file_validation 0:00:00.017892

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.017892
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_invalid_filepath 0:00:00.036714

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.036714
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_file 0:00:00.043257

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.043257
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_param_acceptance 0:00:00.038426

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.038426
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_allfine 0:00:00.036204

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.036204
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_badcomment 0:00:00.017757

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.017757
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_nojson 0:00:00.017334

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.017334
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_schema_violation 0:00:00.027483

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.027483
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_undecodable_val 0:00:00.017360

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.017360
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_plain_args 0:00:00.035580

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.035580
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_dict_validity 0:00:00.045799

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.045799
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_jsonable_dict 0:00:00.037928

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:49:58
Duration | 0:00:00.037928
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_controller.py 5 0:03:09.130912

### PASSED Test_EnPT_Controller::test_run_all_processors 0:00:08.347872

Started | 2025-09-04 12:49:58
Ended | 2025-09-04 12:50:07
Duration | 0:00:08.347872
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': True,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': True,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/dem_map_geo.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest1_CWV2_SM0.zip',
                      'path_l1b_enmap_image_gapfill': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest2_CWV2_SM0.zip',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmp1k_9mbru'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': False,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/04 12:49:59:   Reading metadata for VNIR detector...
    2025/09/04 12:49:59:   Calculating solar irradiance...
    2025/09/04 12:49:59:   Reading metadata for SWIR detector...
    2025/09/04 12:49:59:   Calculating solar irradiance...
    2025/09/04 12:49:59:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:49:59:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:50:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:50:00:   Reading metadata for VNIR detector...
    2025/09/04 12:50:00:   Calculating solar irradiance...
    2025/09/04 12:50:00:   Reading metadata for SWIR detector...
    2025/09/04 12:50:00:   Calculating solar irradiance...
    2025/09/04 12:50:00:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:50:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:50:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:50:00:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:50:00:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:50:00:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:50:00:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:50:00:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:50:01:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:50:02:   Skipping atmospheric correction as configured and computing top-of-atmosphere reflectance instead.
    2025/09/04 12:50:02:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/04 12:50:02:   Converting TOA radiance to TOA reflectance for SWIR detector...
    2025/09/04 12:50:02:   Starting orthorectification...
    2025/09/04 12:50:02:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257740.0, 656040.0, 5266620.0)
    2025/09/04 12:50:02:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:50:03:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:50:04:   Merging VNIR and SWIR data...
    2025/09/04 12:50:04:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:50:05:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:50:05:   Generating L2A metadata...
    2025/09/04 12:50:06:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (296, 958, 209) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.TIF.
    Writing GeoArray of size (296, 958) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:50:07:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_header.xml
    2025/09/04 12:50:07:   L2A product successfully written!
    2025/09/04 12:50:07:   Total runtime of the processing chain: 0:00:08.279813

##### Captured stderr call

    2025/09/04 12:50:00:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:50:00:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:50:00:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:50:00:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:50:00:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:50:06:   The 'mask_landwater' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'mask_cloudshadow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'mask_haze' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'mask_snow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'mask_cirrus' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/04 12:50:06:   The 'sicor_cwv' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'sicor_liq' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'sicor_ice' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:06:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:50:07:   No XML metadata conversion implemented for datasets different to the DLR format.Metadata XML file will be empty.

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata::test_run_all_processors 0:00:58.613061

Started | 2025-09-04 12:50:07
Ended | 2025-09-04 12:51:05
Duration | 0:00:58.613061
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 24,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-799.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpdggxz1dd'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': True,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/T30TXQ_20170218T110111_B05__sub.tif'},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/04 12:50:07:   Reading metadata for VNIR detector...
    2025/09/04 12:50:07:   Calculating solar irradiance...
    2025/09/04 12:50:07:   Reading metadata for SWIR detector...
    2025/09/04 12:50:08:   Calculating solar irradiance...
    2025/09/04 12:50:08:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:50:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:50:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:50:08:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:50:09:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:50:09:   Computing VNIR geolayer...
    2025/09/04 12:50:09:   Computing SWIR geolayer...
    2025/09/04 12:50:09:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/09/04 12:50:10:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/09/04 12:50:10:   Preparing reference image for co-registration.
    2025/09/04 12:50:10:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/09/04 12:50:21:   Generating misregistration array.
    interpolation runtime: 0.22s
    interpolation runtime: 0.18s
    2025/09/04 12:50:22:   Transforming spatial optimization results back to sensor geometry.
    2025/09/04 12:50:22:   Applying results of spatial optimization to geolayer.
    2025/09/04 12:50:22:   Pre-processing DEM for VNIR...
    2025/09/04 12:50:22:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/04 12:50:23:   Pre-processing DEM for SWIR...
    2025/09/04 12:50:23:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/04 12:50:23:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/04 12:50:23:   Starting atmospheric correction for VNIR and SWIR detector in 'land' mode. Source radiometric unit code is 'TOARad'.
    2025/09/04 12:50:23:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/09/04 12:50:23:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 24,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/04 12:50:23:   Setting up forward operator...
    2025/09/04 12:50:23:   SICOR is applied to land AND water pixels.
    2025/09/04 12:50:23:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/04 12:50:25:   Getting observation metadata...
    2025/09/04 12:50:25:   Checking if observation metadata values are within LUT value ranges...
    2025/09/04 12:50:25:   Loading solar irradiance model...
    2025/09/04 12:50:25:   Loading RT LUT...
    2025/09/04 12:50:25:   LUT file was properly downloaded and is available for AC!
    2025/09/04 12:50:25:   Converting LUT to Fontenla solar model...
    2025/09/04 12:50:25:   Resampling LUT to EnMAP wavelengths...
    2025/09/04 12:50:47:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/04 12:50:48:   Calculating absorption coefficients of liquid water and ice...
    2025/09/04 12:50:48:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/04 12:50:49:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/04 12:50:50:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/04 12:50:50:   Performing first guess ice retrieval based on the NDSI...
    2025/09/04 12:50:50:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/04 12:50:50:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/04 12:50:50:   Preparing segmented SWIR L1B data cube...
    2025/09/04 12:50:51:   Performing 3 phases of water retrieval...
    2025/09/04 12:50:51:   Setting up multiprocessing...
    2025/09/04 12:50:51:   Multiprocessing on 24 cpu's
    2025/09/04 12:50:51:   Preparing optimal estimation input...
    2025/09/04 12:50:51:   Optimization...
    2025/09/04 12:50:53:   Done!
    2025/09/04 12:50:53:   Runtime: 2.24 s
    2025/09/04 12:50:53:   Smoothing segmented CWV retrieval map...
    2025/09/04 12:50:53:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/04 12:50:53:   Starting surface reflectance retrieval...
    2025/09/04 12:50:53:   Calculating surface reflectance for vnir detector...
    2025/09/04 12:50:56:   Calculating surface reflectance for swir detector...
    2025/09/04 12:50:59:   Smoothing segmented liquid water and ice maps...
    2025/09/04 12:50:59:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/09/04 12:50:59:   Joining results of atmospheric correction.
    2025/09/04 12:50:59:   Starting orthorectification...
    2025/09/04 12:50:59:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636960.0, 4940670.0, 666090.0, 4949310.0)
    2025/09/04 12:50:59:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:51:00:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:51:01:   Merging VNIR and SWIR data...
    2025/09/04 12:51:01:   Orthorectifying 'mask_landwater' attribute...
    2025/09/04 12:51:01:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:51:02:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/04 12:51:02:   Orthorectifying 'mask_haze' attribute...
    2025/09/04 12:51:02:   Orthorectifying 'mask_snow' attribute...
    2025/09/04 12:51:02:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/04 12:51:02:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/04 12:51:03:   Orthorectifying 'sicor_liq' attribute...
    2025/09/04 12:51:03:   Orthorectifying 'sicor_ice' attribute...
    2025/09/04 12:51:03:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:51:04:   Generating L2A metadata...
    2025/09/04 12:51:04:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (288, 971, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    2025/09/04 12:51:05:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/04 12:51:05:   L2A product successfully written!
    2025/09/04 12:51:05:   Total runtime of the processing chain: 0:00:58.545567

##### Captured stderr call

    2025/09/04 12:50:07:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/04 12:50:09:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.8% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.3% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.3% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.2% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.2% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.3% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.3% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.2% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.3% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.3% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.4% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.1% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.4% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.5% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.4% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.0% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.6% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.4% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.0% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.0% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.3% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.3% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.2% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.1% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.3% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.3% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.3% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.3% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.6% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.2% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.2% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:09
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:09
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:09
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:09
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:09
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:09
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:09
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:09
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:09
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:09
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:09
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:09
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:09
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:09
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:09
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:09
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:09
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:09
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:09
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:09
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:09
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:09
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:09
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:09
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:10
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:10
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:10
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:10
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:10
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:10
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:10
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:10
    	progress: |============================----------------------| 55.3% Complete  => 0:00:10
    	progress: |============================----------------------| 55.9% Complete  => 0:00:10
    	progress: |============================----------------------| 56.5% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:10
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:10
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:10
    	progress: |================================------------------| 63.4% Complete  => 0:00:10
    	progress: |================================------------------| 64.0% Complete  => 0:00:10
    	progress: |================================------------------| 64.6% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:10
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:10
    	progress: |==================================----------------| 67.1% Complete  => 0:00:10
    	progress: |==================================----------------| 67.7% Complete  => 0:00:10
    	progress: |==================================----------------| 68.3% Complete  => 0:00:10
    	progress: |==================================----------------| 68.9% Complete  => 0:00:10
    	progress: |===================================---------------| 69.6% Complete  => 0:00:10
    	progress: |===================================---------------| 70.2% Complete  => 0:00:10
    	progress: |===================================---------------| 70.8% Complete  => 0:00:10
    	progress: |====================================--------------| 71.4% Complete  => 0:00:10
    	progress: |====================================--------------| 72.0% Complete  => 0:00:10
    	progress: |====================================--------------| 72.7% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:10
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:10
    	progress: |======================================------------| 75.2% Complete  => 0:00:10
    	progress: |======================================------------| 75.8% Complete  => 0:00:10
    	progress: |======================================------------| 76.4% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:10
    	progress: |========================================----------| 79.5% Complete  => 0:00:10
    	progress: |========================================----------| 80.1% Complete  => 0:00:10
    	progress: |========================================----------| 80.7% Complete  => 0:00:10
    	progress: |=========================================---------| 81.4% Complete  => 0:00:10
    	progress: |=========================================---------| 82.0% Complete  => 0:00:10
    	progress: |=========================================---------| 82.6% Complete  => 0:00:10
    	progress: |==========================================--------| 83.2% Complete  => 0:00:10
    	progress: |==========================================--------| 83.9% Complete  => 0:00:10
    	progress: |==========================================--------| 84.5% Complete  => 0:00:10
    	progress: |===========================================-------| 85.1% Complete  => 0:00:10
    	progress: |===========================================-------| 85.7% Complete  => 0:00:10
    	progress: |===========================================-------| 86.3% Complete  => 0:00:10
    	progress: |===========================================-------| 87.0% Complete  => 0:00:10
    	progress: |============================================------| 87.6% Complete  => 0:00:10
    	progress: |============================================------| 88.2% Complete  => 0:00:10
    	progress: |============================================------| 88.8% Complete  => 0:00:10
    	progress: |=============================================-----| 89.4% Complete  => 0:00:10
    	progress: |=============================================-----| 90.1% Complete  => 0:00:10
    	progress: |=============================================-----| 90.7% Complete  => 0:00:10
    	progress: |==============================================----| 91.3% Complete  => 0:00:10
    	progress: |==============================================----| 91.9% Complete  => 0:00:10
    	progress: |==============================================----| 92.5% Complete  => 0:00:10
    	progress: |===============================================---| 93.2% Complete  => 0:00:10
    	progress: |===============================================---| 93.8% Complete  => 0:00:10
    	progress: |===============================================---| 94.4% Complete  => 0:00:10
    	progress: |================================================--| 95.0% Complete  => 0:00:10
    	progress: |================================================--| 95.7% Complete  => 0:00:10
    	progress: |================================================--| 96.3% Complete  => 0:00:10
    	progress: |================================================--| 96.9% Complete  => 0:00:10
    	progress: |=================================================-| 97.5% Complete  => 0:00:10
    	progress: |=================================================-| 98.1% Complete  => 0:00:10
    	progress: |=================================================-| 98.8% Complete  => 0:00:10
    	progress: |==================================================| 99.4% Complete  => 0:00:10
    	progress: |==================================================| 100.0% Complete  => 0:00:10

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 4.4% Complete  => 0:00:00
    	progress: |====----------------------------------------------| 7.6% Complete  => 0:00:00
    	progress: |==========----------------------------------------| 19.6% Complete  => 0:00:00
    	progress: |==============------------------------------------| 27.6% Complete  => 0:00:00
    	progress: |=====================-----------------------------| 41.8% Complete  => 0:00:01
    	progress: |================================------------------| 64.4% Complete  => 0:00:01
    	progress: |========================================----------| 80.9% Complete  => 0:00:01
    	progress: |=================================================-| 98.2% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/09/04 12:50:59:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/04 12:50:59:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/04 12:51:05:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/04 12:51:05:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:51:05:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:51:05:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_import_polymer 0:00:00.038013

Started | 2025-09-04 12:51:05
Ended | 2025-09-04 12:51:05
Duration | 0:00:00.038013
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors 0:01:23.697080

Started | 2025-09-04 12:51:05
Ended | 2025-09-04 12:52:29
Duration | 0:01:23.697080
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpyoe2tkxd'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/04 12:51:05:   Reading metadata for VNIR detector...
    2025/09/04 12:51:06:   Calculating solar irradiance...
    2025/09/04 12:51:06:   Reading metadata for SWIR detector...
    2025/09/04 12:51:06:   Calculating solar irradiance...
    2025/09/04 12:51:06:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:51:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:51:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:51:06:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:51:07:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:51:07:   Computing VNIR geolayer...
    2025/09/04 12:51:07:   Computing SWIR geolayer...
    2025/09/04 12:51:07:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:51:07:   Percentage of defective pixels: 0.49
    2025/09/04 12:51:07:   Percentage of pixels with a defect in any band: 35.60
    2025/09/04 12:51:07:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:51:07:   Percentage of defective pixels: 0.50
    2025/09/04 12:51:07:   Percentage of pixels with a defect in any band: 44.50
    2025/09/04 12:51:07:   Pre-processing DEM for VNIR...
    2025/09/04 12:51:07:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/04 12:51:07:   Pre-processing DEM for SWIR...
    2025/09/04 12:51:07:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/04 12:51:07:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/04 12:51:08:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/09/04 12:51:08:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': True,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/04 12:51:08:   Setting up forward operator...
    2025/09/04 12:51:08:   SICOR is applied to land pixels only. This may result in edge effects, e.g., at coastlines...
    2025/09/04 12:51:08:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/04 12:51:09:   Getting observation metadata...
    2025/09/04 12:51:09:   Checking if observation metadata values are within LUT value ranges...
    2025/09/04 12:51:09:   Loading solar irradiance model...
    2025/09/04 12:51:09:   Loading RT LUT...
    2025/09/04 12:51:09:   LUT file was properly downloaded and is available for AC!
    2025/09/04 12:51:09:   Converting LUT to Fontenla solar model...
    2025/09/04 12:51:09:   Resampling LUT to EnMAP wavelengths...
    2025/09/04 12:51:28:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/04 12:51:29:   Calculating absorption coefficients of liquid water and ice...
    2025/09/04 12:51:29:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/04 12:51:30:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/04 12:51:30:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/04 12:51:30:   Performing first guess ice retrieval based on the NDSI...
    2025/09/04 12:51:30:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/04 12:51:30:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/04 12:51:31:   Preparing segmented SWIR L1B data cube...
    2025/09/04 12:51:32:   Performing 3 phases of water retrieval...
    2025/09/04 12:51:32:   Setting up multiprocessing...
    2025/09/04 12:51:32:   Multiprocessing on 16 cpu's
    2025/09/04 12:51:32:   Preparing optimal estimation input...
    2025/09/04 12:51:32:   Optimization...
    2025/09/04 12:51:33:   Done!
    2025/09/04 12:51:33:   Runtime: 1.41 s
    2025/09/04 12:51:33:   Smoothing segmented CWV retrieval map...
    2025/09/04 12:51:33:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/04 12:51:33:   Starting surface reflectance retrieval...
    2025/09/04 12:51:33:   Calculating surface reflectance for vnir detector...
    2025/09/04 12:51:35:   Calculating surface reflectance for swir detector...
    2025/09/04 12:51:36:   Smoothing segmented liquid water and ice maps...
    2025/09/04 12:51:36:   SICOR atmospheric correction for EnMAP in combined mode successfully finished!
    vnir
    2025/09/04 12:51:36:   Running polymer...
    Initializing ENMAP product of size (30, 1000)
    2025/09/04 12:51:36:   Landmask is EnMAP L1B
    Starting processing at 2025-09-04 12:51:37.209639
    Processing block: size (30, 1000), offset (0, 0)
    Done in 0:00:47.043009
    2025/09/04 12:52:24:   Joining results of atmospheric correction.
    2025/09/04 12:52:24:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/09/04 12:52:24:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:52:24:   Percentage of defective pixels: 0.49
    2025/09/04 12:52:24:   Percentage of pixels with a defect in any band: 35.60
    2025/09/04 12:52:24:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:52:24:   Percentage of defective pixels: 0.50
    2025/09/04 12:52:24:   Percentage of pixels with a defect in any band: 44.50
    2025/09/04 12:52:24:   Starting orthorectification...
    2025/09/04 12:52:24:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/09/04 12:52:24:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:52:25:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:52:25:   Merging VNIR and SWIR data...
    2025/09/04 12:52:25:   Orthorectifying 'mask_landwater' attribute...
    2025/09/04 12:52:25:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:52:26:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/04 12:52:26:   Orthorectifying 'mask_haze' attribute...
    2025/09/04 12:52:26:   Orthorectifying 'mask_snow' attribute...
    2025/09/04 12:52:26:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/04 12:52:26:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/04 12:52:26:   Orthorectifying 'sicor_liq' attribute...
    2025/09/04 12:52:26:   Orthorectifying 'sicor_ice' attribute...
    2025/09/04 12:52:27:   Orthorectifying 'polymer_logchl' attribute...
    2025/09/04 12:52:27:   Orthorectifying 'polymer_logfb' attribute...
    2025/09/04 12:52:27:   Orthorectifying 'polymer_rgli' attribute...
    2025/09/04 12:52:27:   Orthorectifying 'polymer_rnir' attribute...
    2025/09/04 12:52:27:   Orthorectifying 'polymer_bitmask' attribute...
    2025/09/04 12:52:27:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:52:28:   Generating L2A metadata...
    2025/09/04 12:52:28:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGCHL.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGFB.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RGLI.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RNIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_BITMASK.TIF.
    2025/09/04 12:52:29:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/04 12:52:29:   L2A product successfully written!
    2025/09/04 12:52:29:   Total runtime of the processing chain: 0:01:23.630203

##### Captured stderr call

    2025/09/04 12:51:05:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=====---------------------------------------------| 9.8% Complete  => 0:00:00
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:00
    	progress: |==================================================| 100.0% Complete  => 0:00:00
    2025/09/04 12:51:36:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/04 12:51:36:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/04 12:52:29:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/04 12:52:29:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:52:29:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:52:29:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors_without_acwater_installed 0:00:38.434886

Test to run all processors while replacing polymer_ac_enmap with None using mock.patch.

Started | 2025-09-04 12:52:29
Ended | 2025-09-04 12:53:07
Duration | 0:00:38.434886
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpvnqtop5w'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/04 12:52:29:   Reading metadata for VNIR detector...
    2025/09/04 12:52:29:   Calculating solar irradiance...
    2025/09/04 12:52:29:   Reading metadata for SWIR detector...
    2025/09/04 12:52:30:   Calculating solar irradiance...
    2025/09/04 12:52:30:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:52:30:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:52:30:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:52:30:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:52:30:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:52:30:   Computing VNIR geolayer...
    2025/09/04 12:52:30:   Computing SWIR geolayer...
    2025/09/04 12:52:30:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:52:31:   Percentage of defective pixels: 0.49
    2025/09/04 12:52:31:   Percentage of pixels with a defect in any band: 35.60
    2025/09/04 12:52:31:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:52:31:   Percentage of defective pixels: 0.50
    2025/09/04 12:52:31:   Percentage of pixels with a defect in any band: 44.50
    2025/09/04 12:52:31:   Pre-processing DEM for VNIR...
    2025/09/04 12:52:31:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/04 12:52:31:   Pre-processing DEM for SWIR...
    2025/09/04 12:52:31:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/04 12:52:31:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/04 12:52:31:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/09/04 12:52:31:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/09/04 12:52:31:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/04 12:52:31:   Setting up forward operator...
    2025/09/04 12:52:31:   SICOR is applied to land AND water pixels.
    2025/09/04 12:52:31:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/04 12:52:32:   Getting observation metadata...
    2025/09/04 12:52:32:   Checking if observation metadata values are within LUT value ranges...
    2025/09/04 12:52:32:   Loading solar irradiance model...
    2025/09/04 12:52:32:   Loading RT LUT...
    2025/09/04 12:52:32:   LUT file was properly downloaded and is available for AC!
    2025/09/04 12:52:32:   Converting LUT to Fontenla solar model...
    2025/09/04 12:52:33:   Resampling LUT to EnMAP wavelengths...
    2025/09/04 12:52:55:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/04 12:52:55:   Calculating absorption coefficients of liquid water and ice...
    2025/09/04 12:52:55:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/04 12:52:57:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/04 12:52:57:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/04 12:52:57:   Performing first guess ice retrieval based on the NDSI...
    2025/09/04 12:52:57:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/04 12:52:57:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/04 12:52:57:   Preparing segmented SWIR L1B data cube...
    2025/09/04 12:52:57:   Performing 3 phases of water retrieval...
    2025/09/04 12:52:57:   Setting up multiprocessing...
    2025/09/04 12:52:57:   Multiprocessing on 16 cpu's
    2025/09/04 12:52:57:   Preparing optimal estimation input...
    2025/09/04 12:52:57:   Optimization...
    2025/09/04 12:52:59:   Done!
    2025/09/04 12:52:59:   Runtime: 2.12 s
    2025/09/04 12:52:59:   Smoothing segmented CWV retrieval map...
    2025/09/04 12:52:59:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/04 12:53:00:   Starting surface reflectance retrieval...
    2025/09/04 12:53:00:   Calculating surface reflectance for vnir detector...
    2025/09/04 12:53:01:   Calculating surface reflectance for swir detector...
    2025/09/04 12:53:03:   Smoothing segmented liquid water and ice maps...
    2025/09/04 12:53:03:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/09/04 12:53:03:   Joining results of atmospheric correction.
    2025/09/04 12:53:03:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/09/04 12:53:03:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:53:03:   Percentage of defective pixels: 0.49
    2025/09/04 12:53:03:   Percentage of pixels with a defect in any band: 35.60
    2025/09/04 12:53:03:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/04 12:53:03:   Percentage of defective pixels: 0.50
    2025/09/04 12:53:03:   Percentage of pixels with a defect in any band: 44.50
    2025/09/04 12:53:04:   Starting orthorectification...
    2025/09/04 12:53:04:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/09/04 12:53:04:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:53:04:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:53:05:   Merging VNIR and SWIR data...
    2025/09/04 12:53:05:   Orthorectifying 'mask_landwater' attribute...
    2025/09/04 12:53:05:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:53:05:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/04 12:53:05:   Orthorectifying 'mask_haze' attribute...
    2025/09/04 12:53:05:   Orthorectifying 'mask_snow' attribute...
    2025/09/04 12:53:05:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/04 12:53:05:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/04 12:53:06:   Orthorectifying 'sicor_liq' attribute...
    2025/09/04 12:53:06:   Orthorectifying 'sicor_ice' attribute...
    2025/09/04 12:53:06:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:53:06:   Generating L2A metadata...
    2025/09/04 12:53:07:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    2025/09/04 12:53:07:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/04 12:53:07:   L2A product successfully written!
    2025/09/04 12:53:07:   Total runtime of the processing chain: 0:00:38.384537

##### Captured stderr call

    2025/09/04 12:52:29:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/04 12:52:31:   Polymer is not callable. As a fallback, SICOR is applied to water surfaces instead.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 6.0% Complete  => 0:00:00
    	progress: |=====---------------------------------------------| 10.2% Complete  => 0:00:00
    	progress: |========------------------------------------------| 16.3% Complete  => 0:00:00
    	progress: |============--------------------------------------| 23.5% Complete  => 0:00:00
    	progress: |=======================---------------------------| 45.8% Complete  => 0:00:00
    	progress: |============================----------------------| 56.0% Complete  => 0:00:01
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:01
    	progress: |====================================--------------| 72.9% Complete  => 0:00:01
    	progress: |==============================================----| 91.6% Complete  => 0:00:01
    	progress: |==================================================| 99.4% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/09/04 12:53:03:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/04 12:53:03:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/04 12:53:07:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/04 12:53:07:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:53:07:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:53:07:   The 'polymer_logchl' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:53:07:   The 'polymer_logfb' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:53:07:   The 'polymer_rgli' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:53:07:   The 'polymer_rnir' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:53:07:   The 'polymer_bitmask' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/04 12:53:07:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

## tests/test_dead_pixel_correction.py 15 0:00:07.958936

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spatial 0:00:03.860578

Started | 2025-09-04 12:53:07
Ended | 2025-09-04 12:53:11
Duration | 0:00:03.860578
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spectral 0:00:00.101347

Started | 2025-09-04 12:53:11
Ended | 2025-09-04 12:53:11
Duration | 0:00:00.101347
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spatial 0:00:03.748370

Started | 2025-09-04 12:53:11
Ended | 2025-09-04 12:53:15
Duration | 0:00:03.748370
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spectral 0:00:00.175663

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.175663
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_0 0:00:00.003005

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.003005
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_1 0:00:00.002627

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.002627
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_bad_args 0:00:00.001198

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.001198
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_2d 0:00:00.002058

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.002058
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_0 0:00:00.002792

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.002792
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_1 0:00:00.003493

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.003493
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_2 0:00:00.046100

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.046100
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_bad_args 0:00:00.001129

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.001129
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_bad_args 0:00:00.001243

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.001243
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_pandas 0:00:00.004535

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.004535
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_scipy 0:00:00.004797

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.004797
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_dem_preprocessing.py 8 0:00:00.389731

### PASSED Test_DEM_Processor::test_compute_aspect 0:00:00.064775

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.064775
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_compute_slopes 0:00:00.028113

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.028113
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_fill_gaps 0:00:00.023710

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.023710
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_get_flat_dem 0:00:00.032853

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:15
Duration | 0:00:00.032853
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_demTooSmall 0:00:00.033858

Started | 2025-09-04 12:53:15
Ended | 2025-09-04 12:53:16
Duration | 0:00:00.033858
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_noWGS84 0:00:00.024251

Started | 2025-09-04 12:53:16
Ended | 2025-09-04 12:53:16
Duration | 0:00:00.024251
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_nomapinfo 0:00:00.022868

Started | 2025-09-04 12:53:16
Ended | 2025-09-04 12:53:16
Duration | 0:00:00.022868
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_to_sensor_geometry 0:00:00.159303

Started | 2025-09-04 12:53:16
Ended | 2025-09-04 12:53:16
Duration | 0:00:00.159303
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_images_sensorgeo.py 6 0:00:24.226270

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr 0:00:02.324051

Started | 2025-09-04 12:53:16
Ended | 2025-09-04 12:53:18
Duration | 0:00:02.324051
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/09/04 12:53:16:   Reading metadata for VNIR detector...
    2025/09/04 12:53:16:   Calculating solar irradiance...
    2025/09/04 12:53:16:   Reading metadata for SWIR detector...
    2025/09/04 12:53:17:   Calculating solar irradiance...
    2025/09/04 12:53:17:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:53:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:53:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:53:17:   Computing VNIR geolayer...
    2025/09/04 12:53:17:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/09/04 12:53:16:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

#### Call

##### Captured stdout call

    2025/09/04 12:53:18:   Transforming the 'mask_snow' attribute from VNIR to SWIR sensor geometry.

##### Captured stderr call

    2025/09/04 12:53:18:   The mask_snow is not yet available in SWIR sensor geometry. Use EnMAP_SWIR_SensorGeo.transform_vnir_to_swir_raster() to set it with a transformed version of the one provided in VNIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr__attrIsNone 0:00:00.006294

Started | 2025-09-04 12:53:18
Ended | 2025-09-04 12:53:18
Duration | 0:00:00.006294
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:53:18:   Transforming the 'mask_haze' attribute from VNIR to SWIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster__no_geolayer 0:00:00.010239

Started | 2025-09-04 12:53:18
Ended | 2025-09-04 12:53:18
Duration | 0:00:00.010239
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster_no_keystone 0:00:01.899463

Started | 2025-09-04 12:53:18
Ended | 2025-09-04 12:53:20
Duration | 0:00:01.899463
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster__no_geolayer 0:00:00.001338

Started | 2025-09-04 12:53:20
Ended | 2025-09-04 12:53:20
Duration | 0:00:00.001338
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster_with_keystone 0:00:19.984885

Started | 2025-09-04 12:53:20
Ended | 2025-09-04 12:53:40
Duration | 0:00:19.984885
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_isofit_enmap.py 65 0:02:10.072943

### PASSED Test_ISOFIT_EnMAP::test__compute_cos_i 0:00:10.292023

Started | 2025-09-04 12:53:40
Ended | 2025-09-04 12:53:50
Duration | 0:00:10.292023
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:53:40:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/04 12:53:40:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/04 12:53:40:   LUT zipfile already downloaded. Proceeding.
    2025/09/04 12:53:40:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Pulling release v1.0.3
    Downloading file
    Unzipping /root/.isofit/isofit-data.zip
    Done, now available at: /root/.isofit/data
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Pulling release v1.2.10
    Downloading file
    Unzipping /root/.isofit/isofit-tutorials.zip
    Downloading NEON data for the example
    Output as: /root/.isofit/examples/isotuts/NEON/data
    Downloading file
    Unzipping /root/.isofit/examples/isotuts/NEON/NEON-subset-data.zip
    Done, now available at: /root/.isofit/examples
    [!] Be sure to build the examples for your system via `isofit build`

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__compute_solar_phase 0:00:00.290975

Started | 2025-09-04 12:53:50
Ended | 2025-09-04 12:53:51
Duration | 0:00:00.290975
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:53:50:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/04 12:53:50:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/04 12:53:51:   LUT zipfile already downloaded. Proceeding.
    2025/09/04 12:53:51:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_6s 0:00:00.001058

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-09-04 12:53:51
Ended | 2025-09-04 12:53:51
Duration | 0:00:00.001058
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 185, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_lut_mod5 0:01:16.591027

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-09-04 12:53:51
Ended | 2025-09-04 12:55:07
Duration | 0:01:16.591027
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:53:51:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/04 12:53:51:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/04 12:53:51:   LUT zipfile already downloaded. Proceeding.
    2025/09/04 12:53:51:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/09/04 12:53:51:   Generating LUT file...
    2025/09/04 12:54:05:   Flightline ID: 20220717T110603Z
    2025/09/04 12:54:05:   no noise path found, proceeding without
    2025/09/04 12:54:05:   Running ISOFIT...
    2025/09/04 12:54:05:   Loading config file: /tmp/tmp8e2xia4s/workdir/config/isofit_config.json
    2025/09/04 12:54:05:   Checking config sections for configuration issues
    2025/09/04 12:54:05:   Configuration file checks complete, no errors found.
    2025/09/04 12:54:13:   Building first forward model, will generate any necessary LUTs
    2025/09/04 12:54:13:   Loading from wavelength_file: /tmp/tmp8e2xia4s/extracted/backtransformed_l2_spectra_v9/enmap_wavelengths.txt
    2025/09/04 12:54:13:   Prebuilt LUT provided
    2025/09/04 12:54:20:   Loading LUT into memory
    2025/09/04 12:54:21:   LUT grid loaded from file: OrderedDict({'AERFRAC_2': [0.05, 0.12, 0.2, 0.3, 0.4, 0.8], 'H2OSTR': [0.0, 1.0, 1.5, 2.0, 2.7, 3.5, 5.0], 'observer_zenith': [0, 10.0, 20.0, 30.0, 40.0], 'relative_azimuth': [0, 25.0, 50.0, 85.0, 120.0, 155.0, 180.0], 'solar_zenith': [0, 10.0, 20.0, 35.0, 50.0, 70.0], 'surface_elevation_km': [0, 0.7, 2.5, 8.0]})
    2025/09/04 12:54:50:   Beginning 100 inversions in 100 chunks using 20 cores
    2025/09/04 12:55:05:   Inversions complete.  14.69s total, 6.8057 spectra/s, 0.3403 spectra/s/core
    2025/09/04 12:55:05:   ISOFIT finished.
    2025/09/04 12:55:05:   Stopping ray.

##### Captured stderr call

    2025/09/04 12:54:05:
    ******************************************************************************************
    ! Number of threads is greater than 1 (currently: 24), this may greatly impact performance
    ! Please set this the environment variables 'MKL_NUM_THREADS' and 'OMP_NUM_THREADS' to '1'
    ******************************************************************************************
    2025-09-04 12:54:09,423	WARNING services.py:2070 -- WARNING: The object store is using /tmp instead of /dev/shm because /dev/shm has only 66887680 bytes available. This will harm performance! You may be able to free up space by deleting files in /dev/shm. If you are inside a Docker container, you can increase /dev/shm size by passing '--shm-size=10.24gb' to 'docker run' (or add it to the run_options list in a Ray cluster config). Make sure to set this to more than 30% of available RAM.
    2025-09-04 12:54:09,723	INFO worker.py:1852 -- Started a local Ray instance.
    WARNING: All log messages before absl::InitializeLog() is called are written to STDERR
    I0000 00:00:1756990505.912533     876 chttp2_transport.cc:1182] ipv4:172.17.0.14:53130: Got goaway [2] err=UNAVAILABLE:GOAWAY received; Error code: 2; Debug Text: Cancelling all calls {grpc_status:14, http2_error:2, created_time:"2025-09-04T12:55:05.91252009+00:00"}

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe__direct_call 0:00:00.000592

Started | 2025-09-04 12:55:07
Ended | 2025-09-04 12:55:07
Duration | 0:00:00.000592
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 120, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe_on_map_geometry 0:00:00.000472

Started | 2025-09-04 12:55:07
Ended | 2025-09-04 12:55:07
Duration | 0:00:00.000472
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 154, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_download_isofit_resources 0:00:02.367821

Started | 2025-09-04 12:55:07
Ended | 2025-09-04 12:55:10
Duration | 0:00:02.367821
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:55:08:   ISOFIT surface spectra zipfile successfully downloaded.
    2025/09/04 12:55:09:   LUT zipfile successfully downloaded.
    2025/09/04 12:55:09:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/04 12:55:09:   LUT zipfile already downloaded. Proceeding.

##### Captured log call

    INFO     test_downloads:_isofit_downloads.py:83 ISOFIT surface spectra zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:83 LUT zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:87 ISOFIT surface spectra zipfile already downloaded. Proceeding.
    INFO     test_downloads:_isofit_downloads.py:87 LUT zipfile already downloaded. Proceeding.

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_generate_input_files 0:00:27.288482

Started | 2025-09-04 12:55:10
Ended | 2025-09-04 12:55:37
Duration | 0:00:27.288482
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:55:10:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/04 12:55:10:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/04 12:55:10:   LUT zipfile already downloaded. Proceeding.
    2025/09/04 12:55:10:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/09/04 12:55:10:   Reading Input Data
    2025/09/04 12:55:10:   Reading metadata for VNIR detector...
    2025/09/04 12:55:10:   Calculating solar irradiance...
    2025/09/04 12:55:10:   Reading metadata for SWIR detector...
    2025/09/04 12:55:11:   Calculating solar irradiance...
    2025/09/04 12:55:11:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:55:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:55:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:55:11:   Computing VNIR geolayer...
    2025/09/04 12:55:12:   Computing SWIR geolayer...
    2025/09/04 12:55:12:   Starting orthorectification...
    2025/09/04 12:55:12:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/09/04 12:55:12:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:55:13:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:55:14:   Merging VNIR and SWIR data...
    2025/09/04 12:55:15:   Orthorectifying 'mask_landwater' attribute...
    2025/09/04 12:55:15:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:55:15:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/04 12:55:15:   Orthorectifying 'mask_haze' attribute...
    2025/09/04 12:55:15:   Orthorectifying 'mask_snow' attribute...
    2025/09/04 12:55:16:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/04 12:55:16:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:55:17:   Generating L2A metadata...
    2025/09/04 12:55:17:   Generating radiance file...
    Writing GeoArray of size (290, 973, 202) to /tmp/tmpl48udqmr/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_rdn.
    2025/09/04 12:55:19:   Generating location file...
    2025/09/04 12:55:19:   Pre-processing DEM in map geometry...
    Automatically detected nodata value for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER': 0.0
    Writing GeoArray of size (290, 973, 3) to /tmp/tmpl48udqmr/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_loc.
    2025/09/04 12:55:19:   Generating observation file...
    Writing GeoArray of size (290, 973, 11) to /tmp/tmpl48udqmr/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_obs.
    2025/09/04 12:55:19:   Generating wavelength file...
    2025/09/04 12:55:19:   Generating surface file for default set of surface coverage types...
    0 ['filtered_other']
    0 ['filtered_veg']
    0 ['filtered_ocean']
    0 ['surface_Liquids']
    1 ['surface_Liquids']
    2025/09/04 12:55:22:   Generating LUT file...

##### Captured stderr call

    2025/09/04 12:55:10:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.0% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.0% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.0% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.1% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.1% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.0% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.0% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.0% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.1% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.0% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.0% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.0% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.0% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.1% Complete  => 0:00:00
    Warping progress     |============================================------| 88.8% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.0% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry 0:00:00.000620

Started | 2025-09-04 12:55:37
Ended | 2025-09-04 12:55:37
Duration | 0:00:00.000620
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 213, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry_no_segmentation 0:00:00.000872

Started | 2025-09-04 12:55:37
Ended | 2025-09-04 12:55:37
Duration | 0:00:00.000872
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 217, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_LUTTransformer::test_modtran_lut_to_netcdf 0:00:13.239001

Started | 2025-09-04 12:55:37
Ended | 2025-09-04 12:55:50
Duration | 0:00:13.239001
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_l1b_reader.py 10 0:01:47.043535

### PASSED Test_L1B_Reader::test_append_100_lines 0:00:16.574221

Started | 2025-09-04 12:55:50
Ended | 2025-09-04 12:56:07
Duration | 0:00:16.574221
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:55:51:   Reading Input Data
    2025/09/04 12:55:51:   Reading metadata for VNIR detector...
    2025/09/04 12:55:51:   Calculating solar irradiance...
    2025/09/04 12:55:51:   Reading metadata for SWIR detector...
    2025/09/04 12:55:51:   Calculating solar irradiance...
    2025/09/04 12:55:51:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:55:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:55:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:55:52:   Reading metadata for VNIR detector...
    2025/09/04 12:55:52:   Calculating solar irradiance...
    2025/09/04 12:55:52:   Reading metadata for SWIR detector...
    2025/09/04 12:55:52:   Calculating solar irradiance...
    2025/09/04 12:55:52:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:55:52:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:55:52:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:55:52:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:52:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:52:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:52:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:53:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgstmonrl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:55:53:   L1B product successfully written!
    2025/09/04 12:55:53:   Reading Input Data
    2025/09/04 12:55:53:   Reading metadata for VNIR detector...
    2025/09/04 12:55:53:   Calculating solar irradiance...
    2025/09/04 12:55:53:   Reading metadata for SWIR detector...
    2025/09/04 12:55:53:   Calculating solar irradiance...
    2025/09/04 12:55:54:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:55:54:   Reading Input Data
    2025/09/04 12:55:54:   Reading metadata for VNIR detector...
    2025/09/04 12:55:54:   Calculating solar irradiance...
    2025/09/04 12:55:54:   Reading metadata for SWIR detector...
    2025/09/04 12:55:54:   Calculating solar irradiance...
    2025/09/04 12:55:54:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:55:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:55:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:55:54:   Reading metadata for VNIR detector...
    2025/09/04 12:55:55:   Calculating solar irradiance...
    2025/09/04 12:55:55:   Reading metadata for SWIR detector...
    2025/09/04 12:55:55:   Calculating solar irradiance...
    2025/09/04 12:55:55:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:55:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:55:55:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:55:55:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:55:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:55:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:55:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:55:55:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:55:57:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:55:57:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4ug6ff2p/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:55:57:   L1B product successfully written!
    2025/09/04 12:55:57:   Reading Input Data
    2025/09/04 12:55:57:   Reading metadata for VNIR detector...
    2025/09/04 12:55:58:   Calculating solar irradiance...
    2025/09/04 12:55:58:   Reading metadata for SWIR detector...
    2025/09/04 12:55:58:   Calculating solar irradiance...
    2025/09/04 12:55:58:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:55:58:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:00:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:00:   Reading Input Data
    2025/09/04 12:56:00:   Reading metadata for VNIR detector...
    2025/09/04 12:56:00:   Calculating solar irradiance...
    2025/09/04 12:56:00:   Reading metadata for SWIR detector...
    2025/09/04 12:56:00:   Calculating solar irradiance...
    2025/09/04 12:56:01:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:01:   Reading metadata for VNIR detector...
    2025/09/04 12:56:01:   Calculating solar irradiance...
    2025/09/04 12:56:01:   Reading metadata for SWIR detector...
    2025/09/04 12:56:01:   Calculating solar irradiance...
    2025/09/04 12:56:01:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:02:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:02:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:02:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0i628r_6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:02:   L1B product successfully written!
    2025/09/04 12:56:02:   Reading Input Data
    2025/09/04 12:56:02:   Reading metadata for VNIR detector...
    2025/09/04 12:56:02:   Calculating solar irradiance...
    2025/09/04 12:56:02:   Reading metadata for SWIR detector...
    2025/09/04 12:56:02:   Calculating solar irradiance...
    2025/09/04 12:56:02:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:02:   Reading Input Data
    2025/09/04 12:56:02:   Reading metadata for VNIR detector...
    2025/09/04 12:56:03:   Calculating solar irradiance...
    2025/09/04 12:56:03:   Reading metadata for SWIR detector...
    2025/09/04 12:56:03:   Calculating solar irradiance...
    2025/09/04 12:56:03:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:03:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:03:   Reading metadata for VNIR detector...
    2025/09/04 12:56:03:   Calculating solar irradiance...
    2025/09/04 12:56:03:   Reading metadata for SWIR detector...
    2025/09/04 12:56:04:   Calculating solar irradiance...
    2025/09/04 12:56:04:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:04:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:04:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:04:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:05:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:05:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprcsl0ioy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:05:   L1B product successfully written!
    2025/09/04 12:56:05:   Reading Input Data
    2025/09/04 12:56:05:   Reading metadata for VNIR detector...
    2025/09/04 12:56:05:   Calculating solar irradiance...
    2025/09/04 12:56:05:   Reading metadata for SWIR detector...
    2025/09/04 12:56:06:   Calculating solar irradiance...
    2025/09/04 12:56:06:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:06:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:06:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/04 12:55:52:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:55:52:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:55:52:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:55:52:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:55:52:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:55:53:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:55:53:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:55:53:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:55:53:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:55:53:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:55:55:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:55:55:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:55:55:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:55:55:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:55:55:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:55:57:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:55:57:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:55:57:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:55:57:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:55:57:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:02:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:02:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:02:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:02:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:02:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:02:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:02:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:04:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:04:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:05:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:05:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:05:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:05:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:05:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_10_lines 0:00:15.215962

Started | 2025-09-04 12:56:07
Ended | 2025-09-04 12:56:22
Duration | 0:00:15.215962
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:56:07:   Reading Input Data
    2025/09/04 12:56:07:   Reading metadata for VNIR detector...
    2025/09/04 12:56:08:   Calculating solar irradiance...
    2025/09/04 12:56:08:   Reading metadata for SWIR detector...
    2025/09/04 12:56:08:   Calculating solar irradiance...
    2025/09/04 12:56:08:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:08:   Reading metadata for VNIR detector...
    2025/09/04 12:56:08:   Calculating solar irradiance...
    2025/09/04 12:56:08:   Reading metadata for SWIR detector...
    2025/09/04 12:56:09:   Calculating solar irradiance...
    2025/09/04 12:56:09:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:09:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:09:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:09:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:09:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:09:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:09:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3oftx_93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:56:09:   L1B product successfully written!
    2025/09/04 12:56:09:   Reading Input Data
    2025/09/04 12:56:09:   Reading metadata for VNIR detector...
    2025/09/04 12:56:10:   Calculating solar irradiance...
    2025/09/04 12:56:10:   Reading metadata for SWIR detector...
    2025/09/04 12:56:10:   Calculating solar irradiance...
    2025/09/04 12:56:10:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:10:   Reading Input Data
    2025/09/04 12:56:10:   Reading metadata for VNIR detector...
    2025/09/04 12:56:10:   Calculating solar irradiance...
    2025/09/04 12:56:10:   Reading metadata for SWIR detector...
    2025/09/04 12:56:11:   Calculating solar irradiance...
    2025/09/04 12:56:11:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:11:   Reading metadata for VNIR detector...
    2025/09/04 12:56:11:   Calculating solar irradiance...
    2025/09/04 12:56:11:   Reading metadata for SWIR detector...
    2025/09/04 12:56:11:   Calculating solar irradiance...
    2025/09/04 12:56:11:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:12:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:12:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:12:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:12:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:12:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:13:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:13:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmperjgn3ff/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:56:13:   L1B product successfully written!
    2025/09/04 12:56:13:   Reading Input Data
    2025/09/04 12:56:13:   Reading metadata for VNIR detector...
    2025/09/04 12:56:13:   Calculating solar irradiance...
    2025/09/04 12:56:14:   Reading metadata for SWIR detector...
    2025/09/04 12:56:14:   Calculating solar irradiance...
    2025/09/04 12:56:14:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:14:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:15:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:15:   Reading Input Data
    2025/09/04 12:56:15:   Reading metadata for VNIR detector...
    2025/09/04 12:56:16:   Calculating solar irradiance...
    2025/09/04 12:56:16:   Reading metadata for SWIR detector...
    2025/09/04 12:56:16:   Calculating solar irradiance...
    2025/09/04 12:56:16:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:16:   Reading metadata for VNIR detector...
    2025/09/04 12:56:16:   Calculating solar irradiance...
    2025/09/04 12:56:16:   Reading metadata for SWIR detector...
    2025/09/04 12:56:17:   Calculating solar irradiance...
    2025/09/04 12:56:17:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:17:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:17:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:17:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp12driwmt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:17:   L1B product successfully written!
    2025/09/04 12:56:17:   Reading Input Data
    2025/09/04 12:56:17:   Reading metadata for VNIR detector...
    2025/09/04 12:56:17:   Calculating solar irradiance...
    2025/09/04 12:56:17:   Reading metadata for SWIR detector...
    2025/09/04 12:56:18:   Calculating solar irradiance...
    2025/09/04 12:56:18:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:18:   Reading Input Data
    2025/09/04 12:56:18:   Reading metadata for VNIR detector...
    2025/09/04 12:56:18:   Calculating solar irradiance...
    2025/09/04 12:56:18:   Reading metadata for SWIR detector...
    2025/09/04 12:56:18:   Calculating solar irradiance...
    2025/09/04 12:56:18:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:18:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:18:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:18:   Reading metadata for VNIR detector...
    2025/09/04 12:56:19:   Calculating solar irradiance...
    2025/09/04 12:56:19:   Reading metadata for SWIR detector...
    2025/09/04 12:56:19:   Calculating solar irradiance...
    2025/09/04 12:56:19:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:19:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:19:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:19:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:20:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:20:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgzvx9_bc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:20:   L1B product successfully written!
    2025/09/04 12:56:20:   Reading Input Data
    2025/09/04 12:56:20:   Reading metadata for VNIR detector...
    2025/09/04 12:56:20:   Calculating solar irradiance...
    2025/09/04 12:56:21:   Reading metadata for SWIR detector...
    2025/09/04 12:56:21:   Calculating solar irradiance...
    2025/09/04 12:56:21:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:21:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:22:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/04 12:56:09:   A minimum of 50 lines is required, only 10 were selected
    2025/09/04 12:56:09:   Set the number of line to 50
    2025/09/04 12:56:09:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:56:09:   A minimum of 50 lines is required, only 10 were selected
    2025/09/04 12:56:09:   Set the number of line to 50
    2025/09/04 12:56:09:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:09:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:12:   A minimum of 50 lines is required, only 10 were selected
    2025/09/04 12:56:12:   Set the number of line to 50
    2025/09/04 12:56:12:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:56:12:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:56:12:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:56:12:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:56:12:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:56:12:   A minimum of 50 lines is required, only 10 were selected
    2025/09/04 12:56:12:   Set the number of line to 50
    2025/09/04 12:56:13:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:13:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:13:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:13:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:13:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:17:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:17:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:17:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:17:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:17:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:19:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:19:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:20:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:20:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:20:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:20:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:20:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_150_lines 0:00:17.097297

Started | 2025-09-04 12:56:22
Ended | 2025-09-04 12:56:39
Duration | 0:00:17.097297
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:56:22:   Reading Input Data
    2025/09/04 12:56:23:   Reading metadata for VNIR detector...
    2025/09/04 12:56:23:   Calculating solar irradiance...
    2025/09/04 12:56:23:   Reading metadata for SWIR detector...
    2025/09/04 12:56:23:   Calculating solar irradiance...
    2025/09/04 12:56:23:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:23:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:23:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:23:   Reading metadata for VNIR detector...
    2025/09/04 12:56:23:   Calculating solar irradiance...
    2025/09/04 12:56:23:   Reading metadata for SWIR detector...
    2025/09/04 12:56:24:   Calculating solar irradiance...
    2025/09/04 12:56:24:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:24:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:24:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:24:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:24:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:24:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvu3du3r/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:56:25:   L1B product successfully written!
    2025/09/04 12:56:25:   Reading Input Data
    2025/09/04 12:56:25:   Reading metadata for VNIR detector...
    2025/09/04 12:56:25:   Calculating solar irradiance...
    2025/09/04 12:56:25:   Reading metadata for SWIR detector...
    2025/09/04 12:56:25:   Calculating solar irradiance...
    2025/09/04 12:56:25:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:25:   Reading Input Data
    2025/09/04 12:56:25:   Reading metadata for VNIR detector...
    2025/09/04 12:56:26:   Calculating solar irradiance...
    2025/09/04 12:56:26:   Reading metadata for SWIR detector...
    2025/09/04 12:56:26:   Calculating solar irradiance...
    2025/09/04 12:56:26:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:26:   Reading metadata for VNIR detector...
    2025/09/04 12:56:26:   Calculating solar irradiance...
    2025/09/04 12:56:26:   Reading metadata for SWIR detector...
    2025/09/04 12:56:27:   Calculating solar irradiance...
    2025/09/04 12:56:27:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:27:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:27:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:27:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:27:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:27:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:28:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:29:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp__9x_zxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:56:29:   L1B product successfully written!
    2025/09/04 12:56:29:   Reading Input Data
    2025/09/04 12:56:29:   Reading metadata for VNIR detector...
    2025/09/04 12:56:29:   Calculating solar irradiance...
    2025/09/04 12:56:29:   Reading metadata for SWIR detector...
    2025/09/04 12:56:30:   Calculating solar irradiance...
    2025/09/04 12:56:30:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:30:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:31:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:32:   Reading Input Data
    2025/09/04 12:56:32:   Reading metadata for VNIR detector...
    2025/09/04 12:56:32:   Calculating solar irradiance...
    2025/09/04 12:56:32:   Reading metadata for SWIR detector...
    2025/09/04 12:56:32:   Calculating solar irradiance...
    2025/09/04 12:56:32:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:32:   Reading metadata for VNIR detector...
    2025/09/04 12:56:32:   Calculating solar irradiance...
    2025/09/04 12:56:33:   Reading metadata for SWIR detector...
    2025/09/04 12:56:33:   Calculating solar irradiance...
    2025/09/04 12:56:33:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:33:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:33:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:33:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:33:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqdio98ty/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:33:   L1B product successfully written!
    2025/09/04 12:56:33:   Reading Input Data
    2025/09/04 12:56:33:   Reading metadata for VNIR detector...
    2025/09/04 12:56:34:   Calculating solar irradiance...
    2025/09/04 12:56:34:   Reading metadata for SWIR detector...
    2025/09/04 12:56:34:   Calculating solar irradiance...
    2025/09/04 12:56:34:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:34:   Reading Input Data
    2025/09/04 12:56:34:   Reading metadata for VNIR detector...
    2025/09/04 12:56:34:   Calculating solar irradiance...
    2025/09/04 12:56:34:   Reading metadata for SWIR detector...
    2025/09/04 12:56:34:   Calculating solar irradiance...
    2025/09/04 12:56:34:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:35:   Reading metadata for VNIR detector...
    2025/09/04 12:56:35:   Calculating solar irradiance...
    2025/09/04 12:56:35:   Reading metadata for SWIR detector...
    2025/09/04 12:56:35:   Calculating solar irradiance...
    2025/09/04 12:56:35:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:36:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:36:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:36:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:36:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:36:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjh5pi17x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:37:   L1B product successfully written!
    2025/09/04 12:56:37:   Reading Input Data
    2025/09/04 12:56:37:   Reading metadata for VNIR detector...
    2025/09/04 12:56:37:   Calculating solar irradiance...
    2025/09/04 12:56:37:   Reading metadata for SWIR detector...
    2025/09/04 12:56:37:   Calculating solar irradiance...
    2025/09/04 12:56:37:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:37:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:39:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/04 12:56:24:   n_lines (150) exceeds the total number of line of second image
    2025/09/04 12:56:24:   Set to the image number of line
    2025/09/04 12:56:24:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:56:24:   n_lines (150) exceeds the total number of line of second image
    2025/09/04 12:56:24:   Set to the image number of line
    2025/09/04 12:56:24:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:24:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:27:   n_lines (150) exceeds the total number of line of second image
    2025/09/04 12:56:27:   Set to the image number of line
    2025/09/04 12:56:27:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:56:27:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:56:27:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:56:27:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:56:27:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:56:27:   n_lines (150) exceeds the total number of line of second image
    2025/09/04 12:56:27:   Set to the image number of line
    2025/09/04 12:56:29:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:29:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:29:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:29:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:29:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:33:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:33:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:33:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:33:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:33:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:33:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:33:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:36:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:36:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:36:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:36:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:36:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:36:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:36:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_50_lines 0:00:16.803359

Started | 2025-09-04 12:56:39
Ended | 2025-09-04 12:56:56
Duration | 0:00:16.803359
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:56:40:   Reading Input Data
    2025/09/04 12:56:40:   Reading metadata for VNIR detector...
    2025/09/04 12:56:40:   Calculating solar irradiance...
    2025/09/04 12:56:40:   Reading metadata for SWIR detector...
    2025/09/04 12:56:41:   Calculating solar irradiance...
    2025/09/04 12:56:41:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:41:   Reading metadata for VNIR detector...
    2025/09/04 12:56:41:   Calculating solar irradiance...
    2025/09/04 12:56:42:   Reading metadata for SWIR detector...
    2025/09/04 12:56:42:   Calculating solar irradiance...
    2025/09/04 12:56:42:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:42:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:42:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:42:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:42:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:42:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:42:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzhin69xd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:56:43:   L1B product successfully written!
    2025/09/04 12:56:43:   Reading Input Data
    2025/09/04 12:56:43:   Reading metadata for VNIR detector...
    2025/09/04 12:56:43:   Calculating solar irradiance...
    2025/09/04 12:56:43:   Reading metadata for SWIR detector...
    2025/09/04 12:56:44:   Calculating solar irradiance...
    2025/09/04 12:56:44:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:44:   Reading Input Data
    2025/09/04 12:56:44:   Reading metadata for VNIR detector...
    2025/09/04 12:56:44:   Calculating solar irradiance...
    2025/09/04 12:56:44:   Reading metadata for SWIR detector...
    2025/09/04 12:56:44:   Calculating solar irradiance...
    2025/09/04 12:56:44:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:45:   Reading metadata for VNIR detector...
    2025/09/04 12:56:45:   Calculating solar irradiance...
    2025/09/04 12:56:45:   Reading metadata for SWIR detector...
    2025/09/04 12:56:45:   Calculating solar irradiance...
    2025/09/04 12:56:45:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:45:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:45:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:45:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:45:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:46:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:47:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:47:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe6utyzu9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:56:47:   L1B product successfully written!
    2025/09/04 12:56:47:   Reading Input Data
    2025/09/04 12:56:47:   Reading metadata for VNIR detector...
    2025/09/04 12:56:47:   Calculating solar irradiance...
    2025/09/04 12:56:47:   Reading metadata for SWIR detector...
    2025/09/04 12:56:48:   Calculating solar irradiance...
    2025/09/04 12:56:48:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:48:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:49:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:49:   Reading Input Data
    2025/09/04 12:56:49:   Reading metadata for VNIR detector...
    2025/09/04 12:56:49:   Calculating solar irradiance...
    2025/09/04 12:56:49:   Reading metadata for SWIR detector...
    2025/09/04 12:56:50:   Calculating solar irradiance...
    2025/09/04 12:56:50:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:50:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:50:   Reading metadata for VNIR detector...
    2025/09/04 12:56:50:   Calculating solar irradiance...
    2025/09/04 12:56:50:   Reading metadata for SWIR detector...
    2025/09/04 12:56:50:   Calculating solar irradiance...
    2025/09/04 12:56:50:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:51:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:51:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:51:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprowx4uas/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:51:   L1B product successfully written!
    2025/09/04 12:56:51:   Reading Input Data
    2025/09/04 12:56:51:   Reading metadata for VNIR detector...
    2025/09/04 12:56:51:   Calculating solar irradiance...
    2025/09/04 12:56:51:   Reading metadata for SWIR detector...
    2025/09/04 12:56:51:   Calculating solar irradiance...
    2025/09/04 12:56:52:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:52:   Reading Input Data
    2025/09/04 12:56:52:   Reading metadata for VNIR detector...
    2025/09/04 12:56:52:   Calculating solar irradiance...
    2025/09/04 12:56:52:   Reading metadata for SWIR detector...
    2025/09/04 12:56:52:   Calculating solar irradiance...
    2025/09/04 12:56:52:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:52:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:52:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:52:   Reading metadata for VNIR detector...
    2025/09/04 12:56:53:   Calculating solar irradiance...
    2025/09/04 12:56:53:   Reading metadata for SWIR detector...
    2025/09/04 12:56:53:   Calculating solar irradiance...
    2025/09/04 12:56:53:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:53:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:53:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:56:53:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:54:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:56:54:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk4sp6l7i/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:56:54:   L1B product successfully written!
    2025/09/04 12:56:54:   Reading Input Data
    2025/09/04 12:56:54:   Reading metadata for VNIR detector...
    2025/09/04 12:56:54:   Calculating solar irradiance...
    2025/09/04 12:56:54:   Reading metadata for SWIR detector...
    2025/09/04 12:56:55:   Calculating solar irradiance...
    2025/09/04 12:56:55:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:55:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:56:56:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/04 12:56:42:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:56:42:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:56:42:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:56:42:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:56:42:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:56:43:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:43:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:43:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:43:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:43:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:45:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:56:45:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:56:45:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:56:45:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:56:45:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:56:47:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:47:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:47:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:47:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:47:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:51:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:51:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:51:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:51:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:51:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:51:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:51:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:56:53:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:53:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:56:54:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:54:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:54:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:54:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:54:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_80_lines 0:00:15.662503

Started | 2025-09-04 12:56:56
Ended | 2025-09-04 12:57:11
Duration | 0:00:15.662503
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:56:56:   Reading Input Data
    2025/09/04 12:56:56:   Reading metadata for VNIR detector...
    2025/09/04 12:56:57:   Calculating solar irradiance...
    2025/09/04 12:56:57:   Reading metadata for SWIR detector...
    2025/09/04 12:56:57:   Calculating solar irradiance...
    2025/09/04 12:56:57:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:57:   Reading metadata for VNIR detector...
    2025/09/04 12:56:57:   Calculating solar irradiance...
    2025/09/04 12:56:57:   Reading metadata for SWIR detector...
    2025/09/04 12:56:58:   Calculating solar irradiance...
    2025/09/04 12:56:58:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:56:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:56:58:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:58:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:58:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:58:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:56:58:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposto4r_k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:56:59:   L1B product successfully written!
    2025/09/04 12:56:59:   Reading Input Data
    2025/09/04 12:56:59:   Reading metadata for VNIR detector...
    2025/09/04 12:56:59:   Calculating solar irradiance...
    2025/09/04 12:56:59:   Reading metadata for SWIR detector...
    2025/09/04 12:56:59:   Calculating solar irradiance...
    2025/09/04 12:56:59:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:56:59:   Reading Input Data
    2025/09/04 12:56:59:   Reading metadata for VNIR detector...
    2025/09/04 12:56:59:   Calculating solar irradiance...
    2025/09/04 12:56:59:   Reading metadata for SWIR detector...
    2025/09/04 12:57:00:   Calculating solar irradiance...
    2025/09/04 12:57:00:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:00:   Reading metadata for VNIR detector...
    2025/09/04 12:57:00:   Calculating solar irradiance...
    2025/09/04 12:57:00:   Reading metadata for SWIR detector...
    2025/09/04 12:57:00:   Calculating solar irradiance...
    2025/09/04 12:57:00:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:01:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:01:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:01:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:01:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:01:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:02:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:57:02:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstjg98um/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:57:03:   L1B product successfully written!
    2025/09/04 12:57:03:   Reading Input Data
    2025/09/04 12:57:03:   Reading metadata for VNIR detector...
    2025/09/04 12:57:03:   Calculating solar irradiance...
    2025/09/04 12:57:03:   Reading metadata for SWIR detector...
    2025/09/04 12:57:03:   Calculating solar irradiance...
    2025/09/04 12:57:03:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:03:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:05:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:57:05:   Reading Input Data
    2025/09/04 12:57:05:   Reading metadata for VNIR detector...
    2025/09/04 12:57:05:   Calculating solar irradiance...
    2025/09/04 12:57:05:   Reading metadata for SWIR detector...
    2025/09/04 12:57:05:   Calculating solar irradiance...
    2025/09/04 12:57:05:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:06:   Reading metadata for VNIR detector...
    2025/09/04 12:57:06:   Calculating solar irradiance...
    2025/09/04 12:57:06:   Reading metadata for SWIR detector...
    2025/09/04 12:57:06:   Calculating solar irradiance...
    2025/09/04 12:57:06:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:06:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:06:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:06:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7uux3zaq/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:57:07:   L1B product successfully written!
    2025/09/04 12:57:07:   Reading Input Data
    2025/09/04 12:57:07:   Reading metadata for VNIR detector...
    2025/09/04 12:57:07:   Calculating solar irradiance...
    2025/09/04 12:57:07:   Reading metadata for SWIR detector...
    2025/09/04 12:57:07:   Calculating solar irradiance...
    2025/09/04 12:57:07:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:07:   Reading Input Data
    2025/09/04 12:57:07:   Reading metadata for VNIR detector...
    2025/09/04 12:57:07:   Calculating solar irradiance...
    2025/09/04 12:57:07:   Reading metadata for SWIR detector...
    2025/09/04 12:57:08:   Calculating solar irradiance...
    2025/09/04 12:57:08:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:08:   Reading metadata for VNIR detector...
    2025/09/04 12:57:08:   Calculating solar irradiance...
    2025/09/04 12:57:08:   Reading metadata for SWIR detector...
    2025/09/04 12:57:09:   Calculating solar irradiance...
    2025/09/04 12:57:09:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:09:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:09:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:09:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:09:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:10:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:57:10:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68jb48z3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:57:10:   L1B product successfully written!
    2025/09/04 12:57:10:   Reading Input Data
    2025/09/04 12:57:10:   Reading metadata for VNIR detector...
    2025/09/04 12:57:10:   Calculating solar irradiance...
    2025/09/04 12:57:10:   Reading metadata for SWIR detector...
    2025/09/04 12:57:10:   Calculating solar irradiance...
    2025/09/04 12:57:10:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:11:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:11:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/04 12:56:58:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:56:58:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:57:01:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:57:01:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:57:01:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:57:01:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:57:01:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:57:02:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:02:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:02:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:02:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:02:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:57:06:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:06:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:06:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:06:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:06:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:06:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:06:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:57:09:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:09:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:10:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:10:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:10:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:10:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:10:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_all_lines 0:00:15.920930

Started | 2025-09-04 12:57:11
Ended | 2025-09-04 12:57:27
Duration | 0:00:15.920930
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:12:   Reading Input Data
    2025/09/04 12:57:12:   Reading metadata for VNIR detector...
    2025/09/04 12:57:12:   Calculating solar irradiance...
    2025/09/04 12:57:12:   Reading metadata for SWIR detector...
    2025/09/04 12:57:13:   Calculating solar irradiance...
    2025/09/04 12:57:13:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:13:   Reading metadata for VNIR detector...
    2025/09/04 12:57:13:   Calculating solar irradiance...
    2025/09/04 12:57:13:   Reading metadata for SWIR detector...
    2025/09/04 12:57:13:   Calculating solar irradiance...
    2025/09/04 12:57:13:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:14:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:14:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:14:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:14:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:14:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:14:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmotq_jri/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:57:14:   L1B product successfully written!
    2025/09/04 12:57:14:   Reading Input Data
    2025/09/04 12:57:14:   Reading metadata for VNIR detector...
    2025/09/04 12:57:14:   Calculating solar irradiance...
    2025/09/04 12:57:14:   Reading metadata for SWIR detector...
    2025/09/04 12:57:15:   Calculating solar irradiance...
    2025/09/04 12:57:15:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:15:   Reading Input Data
    2025/09/04 12:57:15:   Reading metadata for VNIR detector...
    2025/09/04 12:57:15:   Calculating solar irradiance...
    2025/09/04 12:57:15:   Reading metadata for SWIR detector...
    2025/09/04 12:57:15:   Calculating solar irradiance...
    2025/09/04 12:57:15:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:15:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:16:   Reading metadata for VNIR detector...
    2025/09/04 12:57:16:   Calculating solar irradiance...
    2025/09/04 12:57:16:   Reading metadata for SWIR detector...
    2025/09/04 12:57:16:   Calculating solar irradiance...
    2025/09/04 12:57:16:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:16:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:16:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:16:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:16:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/04 12:57:17:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:18:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:57:18:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp66g41dr0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:57:18:   L1B product successfully written!
    2025/09/04 12:57:18:   Reading Input Data
    2025/09/04 12:57:19:   Reading metadata for VNIR detector...
    2025/09/04 12:57:19:   Calculating solar irradiance...
    2025/09/04 12:57:19:   Reading metadata for SWIR detector...
    2025/09/04 12:57:19:   Calculating solar irradiance...
    2025/09/04 12:57:19:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:19:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:21:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:57:21:   Reading Input Data
    2025/09/04 12:57:21:   Reading metadata for VNIR detector...
    2025/09/04 12:57:21:   Calculating solar irradiance...
    2025/09/04 12:57:21:   Reading metadata for SWIR detector...
    2025/09/04 12:57:21:   Calculating solar irradiance...
    2025/09/04 12:57:21:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:21:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:21:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:22:   Reading metadata for VNIR detector...
    2025/09/04 12:57:22:   Calculating solar irradiance...
    2025/09/04 12:57:22:   Reading metadata for SWIR detector...
    2025/09/04 12:57:22:   Calculating solar irradiance...
    2025/09/04 12:57:22:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:22:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:22:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:22:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbu241dj0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:57:23:   L1B product successfully written!
    2025/09/04 12:57:23:   Reading Input Data
    2025/09/04 12:57:23:   Reading metadata for VNIR detector...
    2025/09/04 12:57:23:   Calculating solar irradiance...
    2025/09/04 12:57:23:   Reading metadata for SWIR detector...
    2025/09/04 12:57:23:   Calculating solar irradiance...
    2025/09/04 12:57:23:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:23:   Reading Input Data
    2025/09/04 12:57:23:   Reading metadata for VNIR detector...
    2025/09/04 12:57:23:   Calculating solar irradiance...
    2025/09/04 12:57:23:   Reading metadata for SWIR detector...
    2025/09/04 12:57:24:   Calculating solar irradiance...
    2025/09/04 12:57:24:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:24:   Reading metadata for VNIR detector...
    2025/09/04 12:57:24:   Calculating solar irradiance...
    2025/09/04 12:57:24:   Reading metadata for SWIR detector...
    2025/09/04 12:57:25:   Calculating solar irradiance...
    2025/09/04 12:57:25:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:25:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:25:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:25:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:25:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/04 12:57:25:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:25:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:57:26:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfhx076o5/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/04 12:57:26:   L1B product successfully written!
    2025/09/04 12:57:26:   Reading Input Data
    2025/09/04 12:57:26:   Reading metadata for VNIR detector...
    2025/09/04 12:57:26:   Calculating solar irradiance...
    2025/09/04 12:57:26:   Reading metadata for SWIR detector...
    2025/09/04 12:57:26:   Calculating solar irradiance...
    2025/09/04 12:57:26:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:26:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:27:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/04 12:57:14:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:14:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:57:16:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/04 12:57:16:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/04 12:57:16:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/04 12:57:16:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/04 12:57:16:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/04 12:57:18:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:18:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:18:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:18:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:18:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:57:22:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:22:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:22:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:22:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:22:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:22:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:22:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/04 12:57:25:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:25:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/04 12:57:26:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:26:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:26:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:26:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:26:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_no_snr 0:00:02.425741

Test to read test image 1, save it and read the saved result again - without SNR.

Started | 2025-09-04 12:57:27
Ended | 2025-09-04 12:57:30
Duration | 0:00:02.425741
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:28:   Reading Input Data
    2025/09/04 12:57:28:   Reading metadata for VNIR detector...
    2025/09/04 12:57:28:   Calculating solar irradiance...
    2025/09/04 12:57:28:   Reading metadata for SWIR detector...
    2025/09/04 12:57:29:   Calculating solar irradiance...
    2025/09/04 12:57:29:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:29:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpegubr2v1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:57:29:   L1B product successfully written!
    2025/09/04 12:57:29:   Reading Input Data
    2025/09/04 12:57:29:   Reading metadata for VNIR detector...
    2025/09/04 12:57:29:   Calculating solar irradiance...
    2025/09/04 12:57:29:   Reading metadata for SWIR detector...
    2025/09/04 12:57:30:   Calculating solar irradiance...
    2025/09/04 12:57:30:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/09/04 12:57:29:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:29:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:29:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:29:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:29:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_with_snr 0:00:03.094842

Test to read test image 1, save it and read the saved result again - with SNR.

Started | 2025-09-04 12:57:30
Ended | 2025-09-04 12:57:33
Duration | 0:00:03.094842
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:30:   Reading Input Data
    2025/09/04 12:57:30:   Reading metadata for VNIR detector...
    2025/09/04 12:57:31:   Calculating solar irradiance...
    2025/09/04 12:57:31:   Reading metadata for SWIR detector...
    2025/09/04 12:57:31:   Calculating solar irradiance...
    2025/09/04 12:57:31:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:31:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:31:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:57:32:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:57:32:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprm0yowih/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/04 12:57:32:   L1B product successfully written!
    2025/09/04 12:57:32:   Reading Input Data
    2025/09/04 12:57:32:   Reading metadata for VNIR detector...
    2025/09/04 12:57:33:   Calculating solar irradiance...
    2025/09/04 12:57:33:   Reading metadata for SWIR detector...
    2025/09/04 12:57:33:   Calculating solar irradiance...
    2025/09/04 12:57:33:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/09/04 12:57:32:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/04 12:57:32:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/04 12:57:32:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/04 12:57:32:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/04 12:57:32:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata 0:00:02.392403

Started | 2025-09-04 12:57:33
Ended | 2025-09-04 12:57:35
Duration | 0:00:02.392403
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:33:   Reading Input Data
    2025/09/04 12:57:33:   Reading metadata for VNIR detector...
    2025/09/04 12:57:33:   Calculating solar irradiance...
    2025/09/04 12:57:33:   Reading metadata for SWIR detector...
    2025/09/04 12:57:34:   Calculating solar irradiance...
    2025/09/04 12:57:34:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:34:   Computing VNIR geolayer...
    2025/09/04 12:57:35:   Computing SWIR geolayer...
    2025/09/04 12:57:35:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_VNIR.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_VNIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.png.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.png.
    2025/09/04 12:57:35:   L1B product successfully written!

##### Captured stderr call

    2025/09/04 12:57:33:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata_dont_drop_bad_bands 0:00:01.856278

Started | 2025-09-04 12:57:35
Ended | 2025-09-04 12:57:37
Duration | 0:00:01.856278
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:35:   Reading Input Data
    2025/09/04 12:57:36:   Reading metadata for VNIR detector...
    2025/09/04 12:57:36:   Calculating solar irradiance...
    2025/09/04 12:57:36:   Reading metadata for SWIR detector...
    2025/09/04 12:57:36:   Calculating solar irradiance...
    2025/09/04 12:57:36:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:36:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:36:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:37:   Computing VNIR geolayer...
    2025/09/04 12:57:37:   Computing SWIR geolayer...

##### Captured stderr call

    2025/09/04 12:57:35:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_orthorectification.py 10 0:00:27.459320

### PASSED Test_Orthorectifier::test_run_transformation_ll 0:00:07.437838

Started | 2025-09-04 12:57:37
Ended | 2025-09-04 12:57:45
Duration | 0:00:07.437838
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:37:   Reading Input Data
    2025/09/04 12:57:38:   Reading metadata for VNIR detector...
    2025/09/04 12:57:38:   Calculating solar irradiance...
    2025/09/04 12:57:38:   Reading metadata for SWIR detector...
    2025/09/04 12:57:38:   Calculating solar irradiance...
    2025/09/04 12:57:38:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:38:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:38:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:39:   Starting orthorectification...
    2025/09/04 12:57:39:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (10.691214991975885, 47.455058810417405, 11.070768, 47.540321)
    2025/09/04 12:57:39:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:57:40:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:57:42:   Merging VNIR and SWIR data...
    2025/09/04 12:57:42:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:57:42:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:57:43:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier::test_run_transformation_utm 0:00:05.148440

Started | 2025-09-04 12:57:45
Ended | 2025-09-04 12:57:50
Duration | 0:00:05.148440
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:45:   Reading Input Data
    2025/09/04 12:57:45:   Reading metadata for VNIR detector...
    2025/09/04 12:57:45:   Calculating solar irradiance...
    2025/09/04 12:57:45:   Reading metadata for SWIR detector...
    2025/09/04 12:57:45:   Calculating solar irradiance...
    2025/09/04 12:57:45:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:46:   Starting orthorectification...
    2025/09/04 12:57:46:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257770.0, 656040.0, 5266620.0)
    2025/09/04 12:57:46:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:57:47:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:57:48:   Merging VNIR and SWIR data...
    2025/09/04 12:57:48:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:57:48:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:57:49:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_ll 0:00:07.069554

Started | 2025-09-04 12:57:50
Ended | 2025-09-04 12:57:57
Duration | 0:00:07.069554
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:50:   Reading Input Data
    2025/09/04 12:57:50:   Reading metadata for VNIR detector...
    2025/09/04 12:57:50:   Calculating solar irradiance...
    2025/09/04 12:57:50:   Reading metadata for SWIR detector...
    2025/09/04 12:57:51:   Calculating solar irradiance...
    2025/09/04 12:57:51:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:51:   Computing VNIR geolayer...
    2025/09/04 12:57:51:   Computing SWIR geolayer...
    2025/09/04 12:57:52:   Starting orthorectification...
    2025/09/04 12:57:52:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (-1.2717290915354968, 44.60009471477741, -0.9054060033197534, 44.68406888113938)
    2025/09/04 12:57:52:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:57:52:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:57:54:   Merging VNIR and SWIR data...
    2025/09/04 12:57:54:   Orthorectifying 'mask_landwater' attribute...
    2025/09/04 12:57:54:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:57:54:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/04 12:57:54:   Orthorectifying 'mask_haze' attribute...
    2025/09/04 12:57:54:   Orthorectifying 'mask_snow' attribute...
    2025/09/04 12:57:55:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/04 12:57:55:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:57:56:   Generating L2A metadata...

##### Captured stderr call

    2025/09/04 12:57:50:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_utm 0:00:07.787453

Started | 2025-09-04 12:57:57
Ended | 2025-09-04 12:58:05
Duration | 0:00:07.787453
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:57:57:   Reading Input Data
    2025/09/04 12:57:57:   Reading metadata for VNIR detector...
    2025/09/04 12:57:57:   Calculating solar irradiance...
    2025/09/04 12:57:57:   Reading metadata for SWIR detector...
    2025/09/04 12:57:58:   Calculating solar irradiance...
    2025/09/04 12:57:58:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:57:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:57:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:57:58:   Computing VNIR geolayer...
    2025/09/04 12:57:58:   Computing SWIR geolayer...
    2025/09/04 12:57:59:   Starting orthorectification...
    2025/09/04 12:57:59:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/09/04 12:57:59:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:58:00:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/04 12:58:01:   Merging VNIR and SWIR data...
    2025/09/04 12:58:01:   Orthorectifying 'mask_landwater' attribute...
    2025/09/04 12:58:01:   Orthorectifying 'mask_clouds' attribute...
    2025/09/04 12:58:01:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/04 12:58:02:   Orthorectifying 'mask_haze' attribute...
    2025/09/04 12:58:02:   Orthorectifying 'mask_snow' attribute...
    2025/09/04 12:58:02:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/04 12:58:02:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/04 12:58:03:   Generating L2A metadata...

##### Captured stderr call

    2025/09/04 12:57:57:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_compute_stack 0:00:00.003383

Started | 2025-09-04 12:58:05
Ended | 2025-09-04 12:58:05
Duration | 0:00:00.003383
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_average 0:00:00.002839

Started | 2025-09-04 12:58:05
Ended | 2025-09-04 12:58:05
Duration | 0:00:00.002839
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_order_by_wvl 0:00:00.002237

Started | 2025-09-04 12:58:05
Ended | 2025-09-04 12:58:05
Duration | 0:00:00.002237
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_swir_only 0:00:00.001951

Started | 2025-09-04 12:58:05
Ended | 2025-09-04 12:58:05
Duration | 0:00:00.001951
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_vnir_only 0:00:00.001950

Started | 2025-09-04 12:58:05
Ended | 2025-09-04 12:58:05
Duration | 0:00:00.001950
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_validate_input 0:00:00.003677

Started | 2025-09-04 12:58:05
Ended | 2025-09-04 12:58:05
Duration | 0:00:00.003677
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_radiometric_transform.py 1 0:00:04.331214

### PASSED Test_Radiometric_Transformer::test_transform_TOARad2TOARef 0:00:04.331214

Started | 2025-09-04 12:58:05
Ended | 2025-09-04 12:58:09
Duration | 0:00:04.331214
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Tmp dir: /tmp/tmphy_v9k95
    2025/09/04 12:58:05:   Reading Input Data
    2025/09/04 12:58:05:   Reading metadata for VNIR detector...
    2025/09/04 12:58:05:   Calculating solar irradiance...
    2025/09/04 12:58:05:   Reading metadata for SWIR detector...
    2025/09/04 12:58:05:   Calculating solar irradiance...
    2025/09/04 12:58:05:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:58:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:58:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:58:06:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:58:06:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:58:07:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/04 12:58:07:   Converting TOA radiance to TOA reflectance for SWIR detector...
    Tmp dir: /tmp/tmp5ozf86jw
    2025/09/04 12:58:07:   Reading Input Data
    2025/09/04 12:58:07:   Reading metadata for VNIR detector...
    2025/09/04 12:58:07:   Calculating solar irradiance...
    2025/09/04 12:58:07:   Reading metadata for SWIR detector...
    2025/09/04 12:58:08:   Calculating solar irradiance...
    2025/09/04 12:58:08:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:58:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:58:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:58:08:   Computing SNR from VNIR TOA radiance.
    2025/09/04 12:58:09:   Computing SNR from SWIR TOA radiance.
    2025/09/04 12:58:09:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/04 12:58:09:   Converting TOA radiance to TOA reflectance for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_optimization.py 1 0:00:15.999196

### PASSED Test_Spatial_Optimizer::test_optimize_geolayer 0:00:15.999196

Started | 2025-09-04 12:58:09
Ended | 2025-09-04 12:58:25
Duration | 0:00:15.999196
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:58:09:   Reading Input Data
    2025/09/04 12:58:09:   Reading metadata for VNIR detector...
    2025/09/04 12:58:09:   Calculating solar irradiance...
    2025/09/04 12:58:09:   Reading metadata for SWIR detector...
    2025/09/04 12:58:10:   Calculating solar irradiance...
    2025/09/04 12:58:10:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:58:10:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:58:10:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:58:10:   Computing VNIR geolayer...
    2025/09/04 12:58:11:   Computing SWIR geolayer...
    2025/09/04 12:58:11:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/09/04 12:58:11:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/09/04 12:58:11:   Preparing reference image for co-registration.
    2025/09/04 12:58:11:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/09/04 12:58:24:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.18s
    2025/09/04 12:58:24:   Transforming spatial optimization results back to sensor geometry.
    2025/09/04 12:58:24:   Applying results of spatial optimization to geolayer.

##### Captured stderr call

    2025/09/04 12:58:09:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/04 12:58:11:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.3% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.3% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.6% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.3% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.6% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.2% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.2% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.1% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.2% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.3% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.7% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.5% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.4% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.2% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.4% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.6% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.6% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.4% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.6% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.4% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.4% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.2% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.8% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.7% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.0% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.4% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.5% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.5% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.1% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.5% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.6% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.4% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.7% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.3% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.8% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.6% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.4% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.5% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.3% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.4% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.6% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.3% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.2% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.2% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.4% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.3% Complete  => 0:00:00
    Warping progress     |================================================--| 95.5% Complete  => 0:00:00
    Warping progress     |================================================--| 96.3% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:10
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:10
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:10
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:10
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:10
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:10
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:10
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:10
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:10
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:10
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:11
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:11
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:11
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:11
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:11
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:11
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:11
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:11
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:11
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:11
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:11
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:11
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:11
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:11
    	progress: |============================----------------------| 55.3% Complete  => 0:00:11
    	progress: |============================----------------------| 55.9% Complete  => 0:00:11
    	progress: |============================----------------------| 56.5% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:11
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:11
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:11
    	progress: |================================------------------| 63.4% Complete  => 0:00:11
    	progress: |================================------------------| 64.0% Complete  => 0:00:11
    	progress: |================================------------------| 64.6% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:11
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:11
    	progress: |==================================----------------| 67.1% Complete  => 0:00:11
    	progress: |==================================----------------| 67.7% Complete  => 0:00:11
    	progress: |==================================----------------| 68.3% Complete  => 0:00:11
    	progress: |==================================----------------| 68.9% Complete  => 0:00:11
    	progress: |===================================---------------| 69.6% Complete  => 0:00:11
    	progress: |===================================---------------| 70.2% Complete  => 0:00:11
    	progress: |===================================---------------| 70.8% Complete  => 0:00:11
    	progress: |====================================--------------| 71.4% Complete  => 0:00:11
    	progress: |====================================--------------| 72.0% Complete  => 0:00:11
    	progress: |====================================--------------| 72.7% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:11
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:11
    	progress: |======================================------------| 75.2% Complete  => 0:00:11
    	progress: |======================================------------| 75.8% Complete  => 0:00:11
    	progress: |======================================------------| 76.4% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:11
    	progress: |========================================----------| 79.5% Complete  => 0:00:11
    	progress: |========================================----------| 80.1% Complete  => 0:00:11
    	progress: |========================================----------| 80.7% Complete  => 0:00:11
    	progress: |=========================================---------| 81.4% Complete  => 0:00:11
    	progress: |=========================================---------| 82.0% Complete  => 0:00:11
    	progress: |=========================================---------| 82.6% Complete  => 0:00:11
    	progress: |==========================================--------| 83.2% Complete  => 0:00:11
    	progress: |==========================================--------| 83.9% Complete  => 0:00:11
    	progress: |==========================================--------| 84.5% Complete  => 0:00:11
    	progress: |===========================================-------| 85.1% Complete  => 0:00:11
    	progress: |===========================================-------| 85.7% Complete  => 0:00:11
    	progress: |===========================================-------| 86.3% Complete  => 0:00:11
    	progress: |===========================================-------| 87.0% Complete  => 0:00:11
    	progress: |============================================------| 87.6% Complete  => 0:00:11
    	progress: |============================================------| 88.2% Complete  => 0:00:11
    	progress: |============================================------| 88.8% Complete  => 0:00:11
    	progress: |=============================================-----| 89.4% Complete  => 0:00:11
    	progress: |=============================================-----| 90.1% Complete  => 0:00:11
    	progress: |=============================================-----| 90.7% Complete  => 0:00:11
    	progress: |==============================================----| 91.3% Complete  => 0:00:11
    	progress: |==============================================----| 91.9% Complete  => 0:00:11
    	progress: |==============================================----| 92.5% Complete  => 0:00:11
    	progress: |===============================================---| 93.2% Complete  => 0:00:11
    	progress: |===============================================---| 93.8% Complete  => 0:00:11
    	progress: |===============================================---| 94.4% Complete  => 0:00:11
    	progress: |================================================--| 95.0% Complete  => 0:00:11
    	progress: |================================================--| 95.7% Complete  => 0:00:11
    	progress: |================================================--| 96.3% Complete  => 0:00:11
    	progress: |================================================--| 96.9% Complete  => 0:00:11
    	progress: |=================================================-| 97.5% Complete  => 0:00:11
    	progress: |=================================================-| 98.1% Complete  => 0:00:11
    	progress: |=================================================-| 98.8% Complete  => 0:00:11
    	progress: |==================================================| 99.4% Complete  => 0:00:11
    	progress: |==================================================| 100.0% Complete  => 0:00:11

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_transform.py 17 0:00:37.201103

### PASSED Test_Geometry_Transformer::test_to_map_geometry 0:00:01.720475

Started | 2025-09-04 12:58:25
Ended | 2025-09-04 12:58:27
Duration | 0:00:01.720475
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:58:25:   Reading Input Data
    2025/09/04 12:58:25:   Reading metadata for VNIR detector...
    2025/09/04 12:58:25:   Calculating solar irradiance...
    2025/09/04 12:58:26:   Reading metadata for SWIR detector...
    2025/09/04 12:58:26:   Calculating solar irradiance...
    2025/09/04 12:58:26:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:58:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:58:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Geometry_Transformer::test_to_sensor_geometry 0:00:01.256709

Started | 2025-09-04 12:58:27
Ended | 2025-09-04 12:58:28
Duration | 0:00:01.256709
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/04 12:58:27:   Reading Input Data
    2025/09/04 12:58:27:   Reading metadata for VNIR detector...
    2025/09/04 12:58:27:   Calculating solar irradiance...
    2025/09/04 12:58:27:   Reading metadata for SWIR detector...
    2025/09/04 12:58:27:   Calculating solar irradiance...
    2025/09/04 12:58:28:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:58:28:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:58:28:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2D 0:00:02.324203

Started | 2025-09-04 12:58:28
Ended | 2025-09-04 12:58:30
Duration | 0:00:02.324203
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/09/04 12:58:28:   Reading Input Data
    2025/09/04 12:58:28:   Reading metadata for VNIR detector...
    2025/09/04 12:58:28:   Calculating solar irradiance...
    2025/09/04 12:58:29:   Reading metadata for SWIR detector...
    2025/09/04 12:58:29:   Calculating solar irradiance...
    2025/09/04 12:58:29:   Reading image masks in VNIR sensor geometry.
    2025/09/04 12:58:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/04 12:58:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/04 12:58:29:   Computing VNIR geolayer...
    2025/09/04 12:58:30:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/09/04 12:58:28:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log setup

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_2DGeolayer 0:00:00.447034

Started | 2025-09-04 12:58:30
Ended | 2025-09-04 12:58:31
Duration | 0:00:00.447034
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_3DGeolayer 0:00:00.413874

Started | 2025-09-04 12:58:31
Ended | 2025-09-04 12:58:31
Duration | 0:00:00.413874
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_2D 0:00:00.428370

Started | 2025-09-04 12:58:31
Ended | 2025-09-04 12:58:32
Duration | 0:00:00.428370
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_3D 0:00:22.516782

Started | 2025-09-04 12:58:32
Ended | 2025-09-04 12:58:54
Duration | 0:00:22.516782
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer 0:00:00.811926

Started | 2025-09-04 12:58:54
Ended | 2025-09-04 12:58:55
Duration | 0:00:00.811926
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:00.444441

Started | 2025-09-04 12:58:55
Ended | 2025-09-04 12:58:55
Duration | 0:00:00.444441
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_normalized_image_coordinates 0:00:00.004327

Started | 2025-09-04 12:58:55
Ended | 2025-09-04 12:58:55
Duration | 0:00:00.004327
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_normalize_coordinates 0:00:00.002748

Started | 2025-09-04 12:58:55
Ended | 2025-09-04 12:58:55
Duration | 0:00:00.002748
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_transform_LonLatHeight_to_RowCol 0:00:00.003036

Started | 2025-09-04 12:58:55
Ended | 2025-09-04 12:58:55
Duration | 0:00:00.003036
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:02.118118

Started | 2025-09-04 12:58:55
Ended | 2025-09-04 12:58:57
Duration | 0:00:02.118118
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_faulty_coeff_set 0:00:00.582840

Test in case of a faulty/inaccurate coeff set the result really does not contain NaNs.

NOTE: NaNs should be filled automatically.

Started | 2025-09-04 12:58:57
Ended | 2025-09-04 12:58:58
Duration | 0:00:00.582840
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_multiprocessing 0:00:02.246496

Started | 2025-09-04 12:58:58
Ended | 2025-09-04 12:59:00
Duration | 0:00:02.246496
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_singleprocessing 0:00:01.421459

Started | 2025-09-04 12:59:00
Ended | 2025-09-04 12:59:02
Duration | 0:00:01.421459
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_one_unique_coeff_set 0:00:00.458265

Started | 2025-09-04 12:59:02
Ended | 2025-09-04 12:59:02
Duration | 0:00:00.458265
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_srf.py 1 0:00:00.005664

### PASSED Test_SRF::test_from_cwl_fwhm 0:00:00.005664

Started | 2025-09-04 12:59:02
Ended | 2025-09-04 12:59:02
Duration | 0:00:00.005664
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown